@@ -45,13 +45,25 @@ def hyphenate(text, margin=2, skip_html=False, hyphen='\u00AD'):
 		tavut = []
 		buff = ''					# parhaillaan tavu jota kursitaan kasaan, on buffissa.
 		rajakerake = None	
+		kerakecount = 0
 		# rajakerake tarkoittaa konsonanttia, josta ei etukäteen tiedä miten tavuraja menee. esim: ka-Na, kaN-nu
 		
 		# Alla esimerkkikommenteissa ISO kirjain viittaa c-muuttujan arvoon eli loopissa käsittelyssä olevaan merkkiin.
 		# Suluissa oleva taas on rajakerake, josta jäi edelliseltä kierrokselta epäselväksi kummalle puolelle tavuviivaa se kuuluu.
 		
-		for c in sana:				
-			
+		for c in sana:
+				
+			if c in kerake:
+				kerakecount += 1
+			else:
+				kerakecount = 0
+			if kerakecount > 3:						# pakotettu tavuraja, että rivit tyyliin kkkkkkkkkk rivittyisivät myös
+				tavut.append(buff+ (rajakerake if rajakerake else ''))
+				buff = c
+				rajakerake = None
+				kerakecount = 1
+				continue
+				
 			# Kirjain voi olla joko vokaali, konsonantti tai välimerkki.
 			
 			if c in vokaali:						
@@ -78,8 +90,8 @@ def hyphenate(text, margin=2, skip_html=False, hyphen='\u00AD'):
 					rajakerake = c
 				elif buff[-1:] in vokaali:		# ääLiö vai pääLlikkö? kaMa, moKa vai kaMpa, mokKa? -> rajakerake
 					rajakerake = c
-				else:							# sKruudata, Riku, Kronikka. konsonanttia toisensa perään... tai puhtaalta pöydältä.
-					buff += c
+				else:
+					buff += c					# sKruudata, Riku, Kronikka. konsonanttia toisensa perään, tai puhtaalta pöydältä.
 					
 			else:				# Välimerkki.
 				if rajakerake:					# japani(n)-matka
@@ -91,15 +103,16 @@ def hyphenate(text, margin=2, skip_html=False, hyphen='\u00AD'):
 					buff += c
 					# tavut.append(buff)	# Oikeasti tässä kulkee tavuraja, mutta välimerkki toimikoon tavumerkin asemasta.
 					# buff = ''
-		
 		if rajakerake:
 			tavut.append( buff + rajakerake)
 		else:
 			tavut.append(buff)
 		tavutettava = ''
+		charcount = 0
 		for tavu in tavut:
 			tavutettava += tavu
-			if len(tavutettava) >= margin and len(tavutettava) <= len(sana) - margin:
+			charcount += len(tavu)
+			if charcount >= margin and charcount <= len(sana) - margin:
 				tavutettava += hyphen
 		valmis_teksti.append( tavutettava )
 	valmis_teksti = ' '.join(valmis_teksti)
